/*
	Sample source file to demonstrate a few features and usage of Combo
	library.
	
	Please ask me at skarkada@aol.com if you have any questions. 
*/
#include <windows.h>
#include "resource.h"

#define APP_NAME		"SAMPLE"

LRESULT CALLBACK _export MainWndProc( HWND, unsigned, WORD, LONG );
LRESULT CALLBACK _export FixCombo( HWND );
LRESULT CALLBACK _export EnableButton( HWND, BOOL, BOOL );

int PASCAL WinMain( HANDLE hInstance, HANDLE hPrevInstance,
                    LPSTR lpszCmdLine, int nCmdShow )
{
    HWND hWnd;
    MSG msg;
    WNDCLASS wndClass;

    if( !hPrevInstance ) {
		wndClass.style = CS_HREDRAW | CS_VREDRAW;
		(FARPROC)wndClass.lpfnWndProc = (FARPROC)MainWndProc;
		wndClass.cbClsExtra = 0;
		wndClass.cbWndExtra = 0;
		wndClass.hInstance = hInstance;
		wndClass.hIcon = LoadIcon( NULL, IDI_APPLICATION );
		wndClass.hCursor = LoadCursor( NULL, IDC_ARROW );
		wndClass.hbrBackground = COLOR_WINDOW + 1;
		wndClass.lpszMenuName = MAKEINTRESOURCE( IDR_MENU1 );
		wndClass.lpszClassName = APP_NAME;

		RegisterClass( &wndClass );
	}

	hWnd = CreateWindow( APP_NAME, APP_NAME, WS_OVERLAPPEDWINDOW,  CW_USEDEFAULT,
		CW_USEDEFAULT, 200, 250, NULL, NULL, hInstance, NULL );

	ShowWindow(hWnd,nCmdShow);
	UpdateWindow(hWnd);

	while( GetMessage( &msg, NULL, 0, 0 ) ){
		TranslateMessage( &msg );
		DispatchMessage( &msg );
	}

    return msg.wParam;
}

LRESULT CALLBACK _export MainWndProc( HWND hWnd, unsigned iMessage,
                                     WORD wParam, LONG lParam )
{
    HINSTANCE hInstance;
    static HWND hWndComboBox;
    BOOL bCurrentState;
    
    switch( iMessage )
    {
    	case WM_CREATE:
    		hInstance = ( (LPCREATESTRUCT) lParam ) -> hInstance;
    		CreateWindow( "STATIC", "Enter some text in the combo box "
    			"and press the + button to add into the list box. "
    			"Select the item and press the - button to delete it "
    			"from the list box. Use Alt + or Alt - while the focus "
    			"is in the combo box to avoid mouse clicks.",
				WS_CHILD | WS_VISIBLE, 
				5, 10, 175, 145, hWnd, 100, hInstance, NULL );
			hWndComboBox = CreateWindow( "COMBOBOX", "", 
				WS_CHILD | WS_VISIBLE | CBS_DROPDOWN, 
				25, 160, 150, 100, hWnd, 101, hInstance, NULL );

    		// Create + and - pushbuttons over the combo box.
    		FixCombo( hWndComboBox );
			return 0;
		case WM_COMMAND:
			switch( wParam ) {
				case ID_FILE_EXIT:
					DestroyWindow( hWnd );
					return 0;
				case ID_MODIFY_PLUSPUSHBUTTON:
				case ID_MODIFY_MINUSPUSHBUTTON:
					bCurrentState = GetMenuState( GetMenu( hWnd ),
						wParam, MF_BYCOMMAND ) & MF_CHECKED;
					EnableButton( hWndComboBox, 
						( wParam == ID_MODIFY_PLUSPUSHBUTTON ), 
						!bCurrentState );
					CheckMenuItem( GetMenu( hWnd ), 
						wParam, MF_BYCOMMAND | 
						( bCurrentState ? MF_UNCHECKED : MF_CHECKED ) );
					return 0;
			}
			break;
		case WM_DESTROY:
			PostQuitMessage( 0 );
			return 0;
	}
	
	return DefWindowProc( hWnd, iMessage, wParam, lParam );
}
